@@ -1,27 +1,36 @@
-import sqlalchemy as db
+from typing import Dict
 
-from dagster import check
-from dagster.core.storage.runs import (
+import sqlalchemy as db
+from packaging.version import parse
+
+import dagster._check as check
+from dagster._core.storage.config import mysql_config
+from dagster._core.storage.runs import (
     DaemonHeartbeatsTable,
     InstanceInfo,
     RunStorageSqlMetadata,
     SqlRunStorage,
 )
-from dagster.core.storage.sql import stamp_alembic_rev  # pylint: disable=unused-import
-from dagster.core.storage.sql import create_engine, run_alembic_upgrade
-from dagster.serdes import ConfigurableClass, ConfigurableClassData, serialize_dagster_namedtuple
-from dagster.utils import utc_datetime_from_timestamp
+from dagster._core.storage.runs.schema import KeyValueStoreTable
+from dagster._core.storage.sql import (
+    check_alembic_revision,
+    create_engine,
+    run_alembic_upgrade,
+    stamp_alembic_rev,
+)
+from dagster._serdes import ConfigurableClass, ConfigurableClassData, serialize_dagster_namedtuple
+from dagster._utils import utc_datetime_from_timestamp
 
 from ..utils import (
-    MYSQL_POOL_RECYCLE,
     create_mysql_connection,
     mysql_alembic_config,
-    mysql_config,
     mysql_url_from_config,
     retry_mysql_connection_fn,
     retry_mysql_creation_fn,
 )
 
+MINIMUM_MYSQL_BUCKET_VERSION = "8.0.0"
+
 
 class MySQLRunStorage(SqlRunStorage, ConfigurableClass):
     """MySQL-backed run storage.
@@ -31,7 +40,7 @@ class MySQLRunStorage(SqlRunStorage, ConfigurableClass):
     ``$DAGSTER_HOME``. Configuration of this class should be done by setting values in that file.
 
 
-    .. literalinclude:: ../../../../../../examples/docs_snippets/docs_snippets/deploying/dagster-mysql.yaml
+    .. literalinclude:: ../../../../../../examples/docs_snippets/docs_snippets/deploying/dagster-mysql-legacy.yaml
        :caption: dagster.yaml
        :start-after: start_marker_runs
        :end-before: end_marker_runs
@@ -65,6 +74,8 @@ class MySQLRunStorage(SqlRunStorage, ConfigurableClass):
         elif "instance_info" not in table_names:
             InstanceInfo.create(self._engine)
 
+        self._mysql_version = self.get_server_version()
+
         super().__init__()
 
     def _init_db(self):
@@ -73,14 +84,14 @@ class MySQLRunStorage(SqlRunStorage, ConfigurableClass):
                 RunStorageSqlMetadata.create_all(conn)
                 stamp_alembic_rev(mysql_alembic_config(__file__), conn)
 
-    def optimize_for_dagit(self, statement_timeout):
+    def optimize_for_dagit(self, statement_timeout, pool_recycle):
         # When running in dagit, hold 1 open connection
         # https://github.com/dagster-io/dagster/issues/3719
         self._engine = create_engine(
             self.mysql_url,
             isolation_level="AUTOCOMMIT",
             pool_size=1,
-            pool_recycle=MYSQL_POOL_RECYCLE,
+            pool_recycle=pool_recycle,
         )
 
     @property
@@ -91,6 +102,13 @@ class MySQLRunStorage(SqlRunStorage, ConfigurableClass):
     def config_type(cls):
         return mysql_config()
 
+    def get_server_version(self):
+        row = self.fetchone("select version()")
+        if not row:
+            return None
+
+        return row[0]
+
     @staticmethod
     def from_config_value(inst_data, config_value):
         return MySQLRunStorage(inst_data=inst_data, mysql_url=mysql_url_from_config(config_value))
@@ -128,6 +146,16 @@ class MySQLRunStorage(SqlRunStorage, ConfigurableClass):
         if migration_name in self._index_migration_cache:
             del self._index_migration_cache[migration_name]
 
+    @property
+    def supports_bucket_queries(self):
+        if not super().supports_bucket_queries:
+            return False
+
+        if not self._mysql_version:
+            return False
+
+        return parse(self._mysql_version) >= parse(MINIMUM_MYSQL_BUCKET_VERSION)
+
     def add_daemon_heartbeat(self, daemon_heartbeat):
         with self.connect() as conn:
             conn.execute(
@@ -144,3 +172,20 @@ class MySQLRunStorage(SqlRunStorage, ConfigurableClass):
                     body=serialize_dagster_namedtuple(daemon_heartbeat),
                 )
             )
+
+    def kvs_set(self, pairs: Dict[str, str]) -> None:
+        check.dict_param(pairs, "pairs", key_type=str, value_type=str)
+        db_values = [{"key": k, "value": v} for k, v in pairs.items()]
+
+        with self.connect() as conn:
+            insert_stmt = db.dialects.mysql.insert(KeyValueStoreTable).values(db_values)
+            conn.execute(
+                insert_stmt.on_duplicate_key_update(
+                    value=insert_stmt.inserted.value,
+                )
+            )
+
+    def alembic_version(self):
+        alembic_config = mysql_alembic_config(__file__)
+        with self.connect() as conn:
+            return check_alembic_revision(alembic_config, conn)
